var a = "PASS";
try {
    throw "FAIL1";
} catch (a__2) {
    var a__2 = "FAIL2";
}
console.log(a);
